@@ -47,7 +47,6 @@ ENV_LOCAL = "USE_LOCAL_SPKR_CACHE"
 
 
 def main():
-
     # Create the argument parser
     parser = argparse.ArgumentParser(
         prog="sonos",
@@ -244,6 +243,7 @@ def main():
             speaker_name = args.parameters[0]
         interactive_loop(
             speaker_name,
+            args.log,
             use_local_speaker_list=use_local_speaker_list,
             no_env=args.no_env,
             single_keystroke=sk,
@@ -266,6 +266,12 @@ def main():
     loop_pointer = -1
 
     loop_start_time = None
+    loop_duration = None
+
+    # Keep track of SPKR environment label insertions, to avoid repeats
+    # when looping
+    env_spkr_inserted = [False for i in range(len(rewindable_sequences))]
+
     for sequence in rewindable_sequences:
         try:
             speaker_name = sequence[0]
@@ -315,7 +321,6 @@ def main():
                     error_report(
                         "Action 'loop_for' requires one parameter (check spaces around the ':' separator)"
                     )
-                loop_duration = 0
                 if loop_start_time is None:
                     loop_start_time = time.time()
                     try:
@@ -340,12 +345,11 @@ def main():
                         continue
                 logging.info("Rewinding to command number {}".format(loop_pointer + 2))
                 rewindable_sequences.rewind_to(loop_pointer + 1)
-                sequence_pointer = loop_pointer
+                sequence_pointer = loop_pointer + 1
                 continue
 
             # Special case: the 'loop_until' action
             if speaker_name.lower() == "loop_until":
-                loop_duration = 0
                 if len(sequence) != 2:
                     error_report(
                         "Action 'loop_until' requires one parameter (check spaces around the ':' separator)"
@@ -374,7 +378,7 @@ def main():
                         continue
                 logging.info("Rewinding to command number {}".format(loop_pointer + 2))
                 rewindable_sequences.rewind_to(loop_pointer + 1)
-                sequence_pointer = loop_pointer
+                sequence_pointer = loop_pointer + 1
                 continue
 
             # Special case: the 'wait' actions
@@ -384,13 +388,15 @@ def main():
 
             # Use the speaker name from the environment?
             if env_speaker:
-                logging.info(
-                    "Getting speaker name '{}' from the $SPKR environment variable".format(
-                        env_speaker
+                if env_spkr_inserted[sequence_pointer] is False:
+                    logging.info(
+                        "Getting speaker name '{}' from the $SPKR environment variable".format(
+                            env_speaker
+                        )
                     )
-                )
-                sequence.insert(0, env_speaker)
-                speaker_name = env_speaker
+                    sequence.insert(0, env_speaker)
+                    speaker_name = env_speaker
+                    env_spkr_inserted[sequence_pointer] = True
 
             # General action processing
             if len(sequence) < 2:
@@ -461,6 +467,11 @@ def main():
                             compact=compact,
                         )
                     # Standard action processing
+                    logging.info(
+                        "Invoking 'run_command' with '{} {} ...'".format(
+                            speaker, action
+                        )
+                    )
                     exit_code, output_msg, error_msg = run_command(
                         speaker,
                         action,
