@@ -1,13 +1,17 @@
 import logging
 import re
 from datetime import datetime, timezone
-from time import sleep
+
+from soco import SoCo  # type: ignore
 
 from soco_cli.api import run_command
 
 
 def track_follow(
-    speaker, use_local_speaker_list=False, break_on_pause=True, compact=False
+    speaker: SoCo,
+    use_local_speaker_list: bool = False,
+    break_on_pause: bool = True,
+    compact: bool = False,
 ):
     """Print out the 'track' details each time the track changes.
 
@@ -16,6 +20,7 @@ def track_follow(
         use_local_speaker_list (bool, optional): Use cached discovery.
         break_on_pause (bool, optional): Whether to return control if the
             speaker enters the paused or stopped playback states.
+        compact (bool, optional): Whether to use 'compact' output mode.
 
     This function operates as if 'outside' the main program logic, because
     it needs to output intermediate results as it executes. Hence, the
@@ -30,7 +35,7 @@ def track_follow(
             return datetime.now(tz=local_tz).strftime("%H:%M")
 
     counter = 1
-    print(flush=True)
+    print()
     while True:
         # If stopped, wait for the speaker to start playback
         _, state, _ = run_command(
@@ -45,7 +50,6 @@ def track_follow(
                     " [{}] Playback is stopped or paused at {}\n".format(
                         speaker.player_name, timestamp()
                     ),
-                    flush=True,
                 )
             else:
                 print(
@@ -129,19 +133,15 @@ def track_follow(
                             else:
                                 first = False
                             output = output + key + " " + value + " "
-
-            print(output, flush=True)
+            print(output)
         else:
             error_out = "{:5d}: [{}] {}".format(
                 counter, timestamp(short=True), error_msg
             )
-            print(error_out, flush=True)
+            print(error_out)
 
         logging.info("Waiting for end of track")
         run_command(
             speaker, "wait_end_track", use_local_speaker_list=use_local_speaker_list
         )
-
-        logging.info("Waiting 1.5s for playback to stabilise")
-        sleep(1.5)
         counter += 1
